# Swifttools python package.

This module presents tools to enable access from Python to some of the web-based
tools supporting the Swift satellite.

In the this release there are a two modules available: [xrt_prods](swifttools/xrt_prods/README.md) and [swift_too](swifttools/swift_too/README.md). 

`xrt_prods` provides a Python interface to the [tools to analyse XRT data](https://www.swift.ac.uk/user_objects). 

`swift_too` provides a Python interface for submitting Swift Target of Opportunity Requests, calculating visibility of targets to Swift, querying observations that Swift has performed and will perform, and other Swift related tools. Documentation for the `swift_too` module can be found here: [https://www.swift.psu.edu/too_api/index.php](https://www.swift.psu.edu/too_api/index.php).

